View source: R/alignment_swap.R
| alignment_swap | R Documentation |
alignment_swap.Complete the alignment of initializations based on the output of function alignment_swap. This function is mainly for people to align the single-task initializations manually. The alignment procedure has been automatically implemented in function mtlgmm and tlgmm. So there is no need to call this function when fitting MTL-GMM or TL-GMM.
alignment_swap(L1, L2, initial_value_list)
L1 |
the component "L1" of the output from function |
L2 |
the component "L2" of the output from function |
initial_value_list |
the output from function |
A list with the following components (well-aligned).
w |
the estimate of mixture proportion in GMMs for each task. Will be a vector. |
mu1 |
the estimate of Gaussian mean in the first cluster of GMMs for each task. Will be a matrix, where each column represents the estimate for a task. |
mu2 |
the estimate of Gaussian mean in the second cluster of GMMs for each task. Will be a matrix, where each column represents the estimate for a task. |
beta |
the estimate of the discriminant coefficient for each task. Will be a matrix, where each column represents the estimate for a task. |
Sigma |
the estimate of the common covariance matrix for each task. Will be a list, where each component represents the estimate for a task. |
For examples, see part "fit signle-task GMMs" of examples in function mtlgmm.
Tian, Y., Weng, H., & Feng, Y. (2022). Unsupervised Multi-task and Transfer Learning on Gaussian Mixture Models. arXiv preprint arXiv:2209.15224.
mtlgmm, tlgmm, predict_gmm, data_generation, initialize, alignment, estimation_error, misclustering_error.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.