View source: R/estimation_error.R
| estimation_error | R Documentation |
Caluclate the estimation error of GMM parameters under the MTL setting (the worst performance among all tasks). Euclidean norms are used.
estimation_error(
estimated_value,
true_value,
parameter = c("w", "mu", "beta", "Sigma")
)
estimated_value |
estimate of GMM parameters. The form of input depends on the parameter |
true_value |
true values of GMM parameters. The form of input depends on the parameter |
parameter |
which parameter to calculate the estimation error for. Can be "w", "mu", "beta", or "Sigma".
|
the largest estimation error among all tasks.
For examples, see examples in function mtlgmm.
Tian, Y., Weng, H., & Feng, Y. (2022). Unsupervised Multi-task and Transfer Learning on Gaussian Mixture Models. arXiv preprint arXiv:2209.15224.
mtlgmm, tlgmm, predict_gmm, data_generation, initialize, alignment, alignment_swap, misclustering_error.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.