alignment_swap.Complete the alignment of initializations based on the output of function alignment_swap. This function is mainly for people to align the single-task initializations manually. The alignment procedure has been automatically implemented in function mtlgmm and tlgmm. So there is no need to call this function when fitting MTL-GMM or TL-GMM.
alignment_swap(L1, L2, initial_value_list)A list with the following components (well-aligned).
the estimate of mixture proportion in GMMs for each task. Will be a vector.
the estimate of Gaussian mean in the first cluster of GMMs for each task. Will be a matrix, where each column represents the estimate for a task.
the estimate of Gaussian mean in the second cluster of GMMs for each task. Will be a matrix, where each column represents the estimate for a task.
the estimate of the discriminant coefficient for each task. Will be a matrix, where each column represents the estimate for a task.
the estimate of the common covariance matrix for each task. Will be a list, where each component represents the estimate for a task.
the component "L1" of the output from function alignment_swap
the component "L2" of the output from function alignment_swap
the output from function initialize
Tian, Y., Weng, H., & Feng, Y. (2022). Unsupervised Multi-task and Transfer Learning on Gaussian Mixture Models. arXiv preprint arXiv:2209.15224.
mtlgmm, tlgmm, predict_gmm, data_generation, initialize, alignment, estimation_error, misclustering_error.